==> pendo_sdk-3.0.0.tar.gz: android/src/main/java/pendo/io/pendo_sdk/PendoFlutterPlugin.java <==
package pendo.io.pendo_sdk;

import android.app.Activity;
import android.app.Application;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import java.util.HashMap;
import java.util.Map;

import android.util.Log;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import sdk.pendo.io.Pendo;
import sdk.pendo.io.sdk.flutter.*;

/**
 * PendoFlutterPlugin
 */
public class PendoFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    final static String pendoChannelName = "pendo_sdk_channel_name";
    private static final String API_CALL_SET_VISITOR_DATA = "setVisitorData";
    private static final String API_CALL_SET_ACCOUNT_DATA = "setAccountData";
    private static final String API_CALL_TRACK = "track";
    private static final String API_CALL_END_SESSION = "endSession";
    private static final String API_CALL_RESUME_GUIDES = "resumeGuides";
    private static final String API_CALL_DISMISS_VISIBLE_GUIDE = "dismissVisibleGuides";
    private static final String API_CALL_PAUSE_GUIDES = "pauseGuides";
    private static final String API_CALL_GET_VISITOR_ID = "getVisitorId";
    private static final String API_CALL_GET_DEVICE_ID = "getDeviceId";
    private static final String API_CALL_GET_ACCOUNT_ID = "getAccountId";
    private static final String API_CALL_SETUP = "setup";
    private static final String API_CALL_START_SESSION = "startSession";
    private static final String API_SET_DEBUG_MODE = "setDebugMode";
    private static final String API_SCREEN_CHANGED = "screenChanged";

    private static final String KEY_APP_KEY = "ApplicationKey";
    private static final String KEY_PENDO_OPTIONS = "PendoOptions";
    private static final String KEY_VISITOR_ID = "VisitorID";
    private static final String KEY_ACCOUNT_ID = "AccountID";
    private static final String KEY_VISITOR_DATA = "VisitorData";
    private static final String KEY_ACCOUNT_DATA = "AccountData";
    private static final String KEY_EVENT_NAME = "EventName";
    private static final String KEY_DISMISS_GUIDES = "DismissGuides";
    private static final String KEY_EVENT_PROPERTIES = "EventProperties";
    private static final String KEY_IS_DEBUG_ENABLED = "IsDebugEnabled";
    private static final String KEY_PLATFORM_VERSION = "PlatformVersion";
    private static final String KEY_INTEGRATION_TYPE = "IntegrationType";
    private static final String KEY_ENV_NAME = "environmentName";
    private static final String KEY_RETROACTIVE_SCREEN_ID = "retroactiveScreenId";
    private static final String KEY_SCREEN_INFO = "info";
    private static final String VAL_INTEGRATION_TYPE_OBSERVABLE = "Observable";
    private static final String VAL_INTEGRATION_TYPE_TRACK = "Track";
    private static final String PENDO_LOG_TAG = "Pendo";

    private Activity mActivity;

    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    /// The FlutterPluginEventDispatcher will be used to dispatch events
    /// coming from the plugin and pass them to the native once it registers to its events
    private FlutterPluginBridge flutterBridge;

    public PendoFlutterPlugin() {
        super();
    }

    /**
     * FlutterPlugin
     **/
    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), pendoChannelName);
        channel.setMethodCallHandler(this);
        flutterBridge = new FlutterPluginBridge(mActivity, flutterPluginBinding.getTextureRegistry());
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        flutterBridge = null;
    }

    /**
     * ActivityAware
     **/
    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.mActivity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        this.mActivity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        this.mActivity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {
        this.mActivity = null;
    }

    /**
     * MethodCallHandler
     **/
    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case API_CALL_START_SESSION:
                startSession(call, result);
                break;

            case API_CALL_SET_VISITOR_DATA:
                setVisitorData(call, result);
                break;

            case API_CALL_SET_ACCOUNT_DATA:
                setAccountData(call, result);
                break;

            case API_CALL_SETUP:
                setup(call, result);
                break;

            case API_CALL_TRACK:
                track(call, result);
                break;

            case API_CALL_END_SESSION:
                endSession(result);
                break;

            case API_CALL_RESUME_GUIDES:
                resumeGuide(result);
                break;

            case API_CALL_DISMISS_VISIBLE_GUIDE:
                dismissVisibleGuides(result);
                break;

            case API_CALL_PAUSE_GUIDES:
                pauseGuides(call, result);
                break;

            case API_CALL_GET_VISITOR_ID:
                getVisitorID(result);
                break;

            case API_CALL_GET_ACCOUNT_ID:
                getAccountId(result);
                break;

            case API_CALL_GET_DEVICE_ID:
                getDeviceId(result);
                break;

            case API_SET_DEBUG_MODE:
                setDebugMode(call, result);
                break;

            case API_SCREEN_CHANGED:
                newScreenIdentified(call, result);
                break;

            default:
                methodNotImplemented(result);
                break;
        }
    }

    private void methodNotImplemented(Result result) {
        result.notImplemented();
    }

    private void setDebugMode(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object isDebugEnabled = arguments.get(KEY_IS_DEBUG_ENABLED);
            if (isDebugEnabled != null) {
                Pendo.setDebugMode((boolean) isDebugEnabled);
            } else {
                Log.w(PENDO_LOG_TAG, "setDebugMode - did not receive a boolean value");
            }
        }
        result.success(null);
    }

    private void getDeviceId(Result result) {
        result.success(Pendo.getDeviceId());
    }

    private void getAccountId(Result result) {
        result.success(Pendo.getAccountId());
    }

    private void getVisitorID(Result result) {
        result.success(Pendo.getVisitorId());
    }

    private void pauseGuides(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object dismissGuides = arguments.get(KEY_DISMISS_GUIDES);
            if (dismissGuides != null) {
                Pendo.pauseGuides((boolean) dismissGuides);
            } else {
                Log.w(PENDO_LOG_TAG, "pauseGuides - did not receive a boolean value");
            }
        }
        result.success(null);
    }

    private void dismissVisibleGuides(Result result) {
        Pendo.dismissVisibleGuides();
        result.success(null);
    }

    private void resumeGuide(Result result) {
        Pendo.resumeGuides();
        result.success(null);
    }

    private void endSession(Result result) {
        Pendo.endSession();
        result.success(null);
    }

    private void track(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object eventName = arguments.get(KEY_EVENT_NAME);
            Object properties = arguments.get(KEY_EVENT_PROPERTIES);
            if (eventName != null) {
                if (isNullOrWhiteSpace((String) eventName)) {
                    Log.e(PENDO_LOG_TAG, "Track - Event name is required");
                } else {
                    Pendo.track((String) eventName, (HashMap) properties);
                }
            }
        }
        result.success(null);
    }

    private void setup(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object appKey = arguments.get(KEY_APP_KEY);
            Object options = arguments.get(KEY_PENDO_OPTIONS);
            String platformVersion = (String) arguments.get(KEY_PLATFORM_VERSION);

            if (appKey != null) {
                Pendo.PendoOptions pendoOptions = createPendoOptions((HashMap) options, platformVersion);
                Pendo.setup(this.mActivity, (String) appKey, pendoOptions, null);
            } else {
                Log.e(PENDO_LOG_TAG, "Setup - appKey is missing");
            }
        }
        result.success(null);
    }

    private void setAccountData(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object accountData = arguments.get(KEY_ACCOUNT_DATA);
            Pendo.setAccountData((HashMap) accountData);
        }
        result.success(null);
    }

    private void setVisitorData(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object visitorData = arguments.get(KEY_VISITOR_DATA);
            Pendo.setVisitorData((HashMap) visitorData);
        }
        result.success(null);
    }

    private void startSession(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object visitorId = arguments.get(KEY_VISITOR_ID);
            Object accountId = arguments.get(KEY_ACCOUNT_ID);
            Object visitorData = arguments.get(KEY_VISITOR_DATA);
            Object accountData = arguments.get(KEY_ACCOUNT_DATA);
            Pendo.startSession((String) visitorId, (String) accountId, (HashMap) visitorData, (HashMap) accountData);
        }
        result.success(null);
    }

    private void newScreenIdentified(MethodCall call, Result result) {
        if (!isEventDispatcherValid()) {
            result.success(null);
            return;
        }
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            String screenName = (String) arguments.get(KEY_RETROACTIVE_SCREEN_ID);
            HashMap screenInfo = (HashMap) arguments.get(KEY_SCREEN_INFO);
            flutterBridge.newScreenIdentified(screenName, screenInfo);
        }
        result.success(null);
    }

    private Pendo.PendoOptions createPendoOptions(@Nullable HashMap options, String platformVersion) {
        Map<String, Object> additionalOptions = new HashMap<>();
        Pendo.PendoOptions.Builder pendoOptions = new Pendo.PendoOptions.Builder()
                .setAdditionalOptions(additionalOptions);
        String integrationType = VAL_INTEGRATION_TYPE_TRACK;
        if (options != null) {
            if(options.containsKey(KEY_ENV_NAME)) {
                String environmentName = (String) options.get(KEY_ENV_NAME);
                if (!isNullOrWhiteSpace(environmentName)) {
                    pendoOptions.setEnvironmentDebugOnly(environmentName);
                }
            }
            if (options.containsKey(KEY_INTEGRATION_TYPE)) {
                if (!isNullOrWhiteSpace((String) options.get(KEY_INTEGRATION_TYPE))) {
                    integrationType = (String)options.get(KEY_INTEGRATION_TYPE);
                }
            }
        }
        additionalOptions.put(Pendo.PendoOptions.FRAMEWORK, Pendo.PendoOptions.Framework.FLUTTER);
        Pendo.PendoOptions.FrameworkType frameworkType;
        if (VAL_INTEGRATION_TYPE_OBSERVABLE.equals(integrationType)) {
            frameworkType = Pendo.PendoOptions.FrameworkType.FLUTTER_OBSERVABLE;
        } else {
            frameworkType = Pendo.PendoOptions.FrameworkType.TRACK;
        }
        additionalOptions.put(Pendo.PendoOptions.FRAMEWORK_TYPE, frameworkType);
        additionalOptions.put(Pendo.PendoOptions.FLUTTER_BRIDGE, flutterBridge);
        additionalOptions.put(Pendo.PendoOptions.FRAMEWORK_VERSION, platformVersion);
        return pendoOptions.build();
    }

    private static boolean isNullOrWhiteSpace(String value) {
        return value == null || value.trim().isEmpty();
    }

    private boolean isEventDispatcherValid() {
        if (flutterBridge == null) {
            Log.e(PENDO_LOG_TAG, "isEventDispatcherValid -> event dispatcher is null");
            return false;
        }
        return true;
    }
}

==> pendo_sdk-3.2.0.tar.gz: android/src/main/java/pendo/io/pendo_sdk/PendoFlutterPlugin.java <==
package pendo.io.pendo_sdk;

import android.app.Activity;
import android.app.Application;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import java.util.HashMap;
import java.util.Map;

import android.util.Log;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import sdk.pendo.io.Pendo;
import sdk.pendo.io.sdk.flutter.*;

/**
 * PendoFlutterPlugin
 */
public class PendoFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    final static String pendoChannelName = "pendo_sdk_channel_name";
    private static final String API_CALL_SET_VISITOR_DATA = "setVisitorData";
    private static final String API_CALL_SET_ACCOUNT_DATA = "setAccountData";
    private static final String API_CALL_TRACK = "track";
    private static final String API_CALL_END_SESSION = "endSession";
    private static final String API_CALL_RESUME_GUIDES = "resumeGuides";
    private static final String API_CALL_DISMISS_VISIBLE_GUIDE = "dismissVisibleGuides";
    private static final String API_CALL_PAUSE_GUIDES = "pauseGuides";
    private static final String API_CALL_GET_VISITOR_ID = "getVisitorId";
    private static final String API_CALL_GET_DEVICE_ID = "getDeviceId";
    private static final String API_CALL_GET_ACCOUNT_ID = "getAccountId";
    private static final String API_CALL_SETUP = "setup";
    private static final String API_CALL_START_SESSION = "startSession";
    private static final String API_SET_DEBUG_MODE = "setDebugMode";
    private static final String API_SCREEN_CHANGED = "screenChanged";

    private static final String KEY_APP_KEY = "ApplicationKey";
    private static final String KEY_PENDO_OPTIONS = "PendoOptions";
    private static final String KEY_VISITOR_ID = "VisitorID";
    private static final String KEY_ACCOUNT_ID = "AccountID";
    private static final String KEY_VISITOR_DATA = "VisitorData";
    private static final String KEY_ACCOUNT_DATA = "AccountData";
    private static final String KEY_EVENT_NAME = "EventName";
    private static final String KEY_DISMISS_GUIDES = "DismissGuides";
    private static final String KEY_EVENT_PROPERTIES = "EventProperties";
    private static final String KEY_IS_DEBUG_ENABLED = "IsDebugEnabled";
    private static final String KEY_PLATFORM_VERSION = "PlatformVersion";
    private static final String KEY_INTEGRATION_TYPE = "IntegrationType";
    private static final String KEY_ENV_NAME = "environmentName";
    private static final String KEY_RETROACTIVE_SCREEN_ID = "retroactiveScreenId";
    private static final String KEY_RETROACTIVE_SCREEN_DATA = "retroactiveScreenData";
    private static final String KEY_SCREEN_INFO = "info";
    private static final String VAL_INTEGRATION_TYPE_OBSERVABLE = "Observable";
    private static final String VAL_INTEGRATION_TYPE_TRACK = "Track";
    private static final String PENDO_LOG_TAG = "Pendo";

    private Activity mActivity;

    /// The MethodChannel that will the communication between Flutter and native
    /// Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine
    /// and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    /// The FlutterPluginEventDispatcher will be used to dispatch events
    /// coming from the plugin and pass them to the native once it registers to its
    /// events
    private FlutterPluginBridge flutterBridge;

    public PendoFlutterPlugin() {
        super();
    }

    /**
     * FlutterPlugin
     **/
    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), pendoChannelName);
        channel.setMethodCallHandler(this);
        flutterBridge = new FlutterPluginBridge(mActivity, flutterPluginBinding.getTextureRegistry());
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        flutterBridge = null;
    }

    /**
     * ActivityAware
     **/
    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.mActivity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        this.mActivity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        this.mActivity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {
        this.mActivity = null;
    }

    /**
     * MethodCallHandler
     **/
    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case API_CALL_START_SESSION:
                startSession(call, result);
                break;

            case API_CALL_SET_VISITOR_DATA:
                setVisitorData(call, result);
                break;

            case API_CALL_SET_ACCOUNT_DATA:
                setAccountData(call, result);
                break;

            case API_CALL_SETUP:
                setup(call, result);
                break;

            case API_CALL_TRACK:
                track(call, result);
                break;

            case API_CALL_END_SESSION:
                endSession(result);
                break;

            case API_CALL_RESUME_GUIDES:
                resumeGuide(result);
                break;

            case API_CALL_DISMISS_VISIBLE_GUIDE:
                dismissVisibleGuides(result);
                break;

            case API_CALL_PAUSE_GUIDES:
                pauseGuides(call, result);
                break;

            case API_CALL_GET_VISITOR_ID:
                getVisitorID(result);
                break;

            case API_CALL_GET_ACCOUNT_ID:
                getAccountId(result);
                break;

            case API_CALL_GET_DEVICE_ID:
                getDeviceId(result);
                break;

            case API_SET_DEBUG_MODE:
                setDebugMode(call, result);
                break;

            case API_SCREEN_CHANGED:
                newScreenIdentified(call, result);
                break;

            default:
                methodNotImplemented(result);
                break;
        }
    }

    private void methodNotImplemented(Result result) {
        result.notImplemented();
    }

    private void setDebugMode(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object isDebugEnabled = arguments.get(KEY_IS_DEBUG_ENABLED);
            if (isDebugEnabled != null) {
                Pendo.setDebugMode((boolean) isDebugEnabled);
            } else {
                Log.w(PENDO_LOG_TAG, "setDebugMode - did not receive a boolean value");
            }
        }
        result.success(null);
    }

    private void getDeviceId(Result result) {
        result.success(Pendo.getDeviceId());
    }

    private void getAccountId(Result result) {
        result.success(Pendo.getAccountId());
    }

    private void getVisitorID(Result result) {
        result.success(Pendo.getVisitorId());
    }

    private void pauseGuides(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object dismissGuides = arguments.get(KEY_DISMISS_GUIDES);
            if (dismissGuides != null) {
                Pendo.pauseGuides((boolean) dismissGuides);
            } else {
                Log.w(PENDO_LOG_TAG, "pauseGuides - did not receive a boolean value");
            }
        }
        result.success(null);
    }

    private void dismissVisibleGuides(Result result) {
        Pendo.dismissVisibleGuides();
        result.success(null);
    }

    private void resumeGuide(Result result) {
        Pendo.resumeGuides();
        result.success(null);
    }

    private void endSession(Result result) {
        Pendo.endSession();
        result.success(null);
    }

    private void track(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object eventName = arguments.get(KEY_EVENT_NAME);
            Object properties = arguments.get(KEY_EVENT_PROPERTIES);
            if (eventName != null) {
                if (isNullOrWhiteSpace((String) eventName)) {
                    Log.e(PENDO_LOG_TAG, "Track - Event name is required");
                } else {
                    Pendo.track((String) eventName, (HashMap) properties);
                }
            }
        }
        result.success(null);
    }

    private void setup(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object appKey = arguments.get(KEY_APP_KEY);
            Object options = arguments.get(KEY_PENDO_OPTIONS);
            String platformVersion = (String) arguments.get(KEY_PLATFORM_VERSION);

            if (appKey != null) {
                Pendo.PendoOptions pendoOptions = createPendoOptions((HashMap) options, platformVersion);
                Pendo.setup(this.mActivity, (String) appKey, pendoOptions, null);
            } else {
                Log.e(PENDO_LOG_TAG, "Setup - appKey is missing");
            }
        }
        result.success(null);
    }

    private void setAccountData(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object accountData = arguments.get(KEY_ACCOUNT_DATA);
            Pendo.setAccountData((HashMap) accountData);
        }
        result.success(null);
    }

    private void setVisitorData(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object visitorData = arguments.get(KEY_VISITOR_DATA);
            Pendo.setVisitorData((HashMap) visitorData);
        }
        result.success(null);
    }

    private void startSession(MethodCall call, Result result) {
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            Object visitorId = arguments.get(KEY_VISITOR_ID);
            Object accountId = arguments.get(KEY_ACCOUNT_ID);
            Object visitorData = arguments.get(KEY_VISITOR_DATA);
            Object accountData = arguments.get(KEY_ACCOUNT_DATA);
            Pendo.startSession((String) visitorId, (String) accountId, (HashMap) visitorData, (HashMap) accountData);
        }
        result.success(null);
    }

    private void newScreenIdentified(MethodCall call, Result result) {
        if (!isEventDispatcherValid()) {
            result.success(null);
            return;
        }
        if (call.arguments instanceof HashMap) {
            HashMap arguments = (HashMap) call.arguments;
            HashMap retroactiveScreenData = (HashMap) arguments.get(KEY_RETROACTIVE_SCREEN_DATA);
            String screenName = (String) retroactiveScreenData.get(KEY_RETROACTIVE_SCREEN_ID);
            flutterBridge.newScreenIdentified(screenName, arguments);
        }
        result.success(null);
    }

    private Pendo.PendoOptions createPendoOptions(@Nullable HashMap options, String platformVersion) {
        Map<String, Object> additionalOptions = new HashMap<>();
        Pendo.PendoOptions.Builder pendoOptions = new Pendo.PendoOptions.Builder()
                .setAdditionalOptions(additionalOptions);
        String integrationType = VAL_INTEGRATION_TYPE_TRACK;
        if (options != null) {
            if (options.containsKey(KEY_ENV_NAME)) {
                String environmentName = (String) options.get(KEY_ENV_NAME);
                if (!isNullOrWhiteSpace(environmentName)) {
                    pendoOptions.setEnvironmentDebugOnly(environmentName);
                }
            }
            if (options.containsKey(KEY_INTEGRATION_TYPE)) {
                if (!isNullOrWhiteSpace((String) options.get(KEY_INTEGRATION_TYPE))) {
                    integrationType = (String) options.get(KEY_INTEGRATION_TYPE);
                }
            }
        }
        additionalOptions.put(Pendo.PendoOptions.FRAMEWORK, Pendo.PendoOptions.Framework.FLUTTER);
        Pendo.PendoOptions.FrameworkType frameworkType;
        if (VAL_INTEGRATION_TYPE_OBSERVABLE.equals(integrationType)) {
            frameworkType = Pendo.PendoOptions.FrameworkType.FLUTTER_OBSERVABLE;
        } else {
            frameworkType = Pendo.PendoOptions.FrameworkType.TRACK;
        }
        additionalOptions.put(Pendo.PendoOptions.FRAMEWORK_TYPE, frameworkType);
        additionalOptions.put(Pendo.PendoOptions.FLUTTER_BRIDGE, flutterBridge);
        additionalOptions.put(Pendo.PendoOptions.FRAMEWORK_VERSION, platformVersion);
        return pendoOptions.build();
    }

    private static boolean isNullOrWhiteSpace(String value) {
        return value == null || value.trim().isEmpty();
    }

    private boolean isEventDispatcherValid() {
        if (flutterBridge == null) {
            Log.e(PENDO_LOG_TAG, "isEventDispatcherValid -> event dispatcher is null");
            return false;
        }
        return true;
    }
}
